==> homerun-0.2.2.tar.bz2: homerun-0.2.2/package/metadata.desktop.cmake <==
[Desktop Entry]
Encoding=UTF-8
# ctxt: "Homerun" is a product name
Name=KDE Homerun
Name[cs]=KDE Homerun
Name[da]=KDE Homerun
Name[de]=KDE Homerun
Name[el]=KDE Homerun
Name[es]=KDE Homerun
Name[et]=KDE Homerun
Name[fi]=KDE Homerun
Name[fr]=Homerun pour KDE
Name[ga]=KDE Homerun
Name[gl]=KDE Homerun
Name[hu]=KDE Homerun
Name[lt]=KDE Homerun
Name[nl]=KDE Homerun
Name[pa]=ਕੇਡੀਈ ਹੋਮਰਨ
Name[pt]=Homerun do KDE
Name[pt_BR]=Homerun do KDE
Name[ro]=KDE Homerun
Name[sk]=KDE Homerun
Name[sv]=KDE Homerun
Name[uk]=KDE Homerun
Name[x-test]=xxKDE Homerunxx
Name[zh_CN]=KDE Homerun
Comment=An application launcher
Comment[da]=Programstarter
Comment[de]=Ein Anwendungsstarter
Comment[el]=Ένας εκτελεστής εφαρμογών
Comment[es]=Un lanzador de aplicaciones
Comment[et]=Rakenduste käivitaja
Comment[fi]=Sovelluskäynnistin
Comment[fr]=Un lanceur d'applications
Comment[gl]=Un lanzador de aplicativos
Comment[hu]=Egy alkalmazásindító
Comment[lt]=Programų leidiklis
Comment[nl]=Een programmastarter
Comment[pa]=ਐਪਲੀਕੇਸ਼ਨ ਲਾਂਚਰ
Comment[pt]=Um lançador de aplicações
Comment[pt_BR]=Um lançador de aplicativos
Comment[ro]=Lansator de aplicații
Comment[sk]=Spúšťač aplikácií
Comment[sv]=Ett startprogram
Comment[uk]=Засіб для запуску програм
Comment[x-test]=xxAn application launcherxx
Comment[zh_CN]=一个应用程序启动器

Icon=homerun
Type=Service
X-KDE-ServiceTypes=Plasma/Containment

#X-KDE-ParentApp=plasma-desktop
X-Plasma-API=declarativeappletscript
X-Plasma-MainScript=ui/main.qml
X-KDE-PluginInfo-Author=Homerun Developers
X-KDE-PluginInfo-Name=org.kde.homerun
X-KDE-PluginInfo-Version=@HOMERUN_VERSION@
X-KDE-PluginInfo-Website=http://userbase.kde.org/Homerun
X-KDE-PluginInfo-Category=Application Launchers
X-KDE-PluginInfo-Depends=
X-KDE-PluginInfo-License=GPL v2+
X-KDE-PluginInfo-EnabledByDefault=true
X-Plasma-DefaultSize=290,340
X-Plasma-ContainmentCategories=desktop

==> homerun-0.2.3.tar.bz2: homerun-0.2.3/package/metadata.desktop.cmake <==
[Desktop Entry]
Encoding=UTF-8
# ctxt: "Homerun" is a product name
Name=KDE Homerun
Name[cs]=KDE Homerun
Name[da]=KDE Homerun
Name[de]=KDE Homerun
Name[el]=KDE Homerun
Name[es]=KDE Homerun
Name[et]=KDE Homerun
Name[fi]=KDE Homerun
Name[fr]=Homerun pour KDE
Name[ga]=KDE Homerun
Name[gl]=KDE Homerun
Name[hu]=KDE Homerun
Name[lt]=KDE Homerun
Name[mr]=केडीई होमरन
Name[nl]=KDE Homerun
Name[pa]=ਕੇਡੀਈ ਹੋਮਰਨ
Name[pt]=Homerun do KDE
Name[pt_BR]=Homerun do KDE
Name[ro]=KDE Homerun
Name[ru]=KDE Homerun
Name[sk]=KDE Homerun
Name[sl]=KDE Homerun
Name[sv]=KDE Homerun
Name[tr]=KDE Homerun
Name[uk]=KDE Homerun
Name[x-test]=xxKDE Homerunxx
Name[zh_CN]=KDE Homerun
Comment=An application launcher
Comment[cs]=Spouštěč aplikací
Comment[da]=Programstarter
Comment[de]=Ein Anwendungsstarter
Comment[el]=Ένας εκτελεστής εφαρμογών
Comment[es]=Un lanzador de aplicaciones
Comment[et]=Rakenduste käivitaja
Comment[fi]=Sovelluskäynnistin
Comment[fr]=Un lanceur d'applications
Comment[gl]=Un lanzador de aplicativos
Comment[hu]=Egy alkalmazásindító
Comment[lt]=Programų leidiklis
Comment[mr]=अनुप्रयोग प्रक्षेपक
Comment[nl]=Een programmastarter
Comment[pa]=ਐਪਲੀਕੇਸ਼ਨ ਲਾਂਚਰ
Comment[pt]=Um lançador de aplicações
Comment[pt_BR]=Um lançador de aplicativos
Comment[ro]=Lansator de aplicații
Comment[ru]=Запуск приложения
Comment[sk]=Spúšťač aplikácií
Comment[sl]=Zaganjalnik programov
Comment[sv]=Ett startprogram
Comment[tr]=Bir uygulama çalıştırıcı
Comment[uk]=Засіб для запуску програм
Comment[x-test]=xxAn application launcherxx
Comment[zh_CN]=一个应用程序启动器

Icon=homerun
Type=Service
X-KDE-ServiceTypes=Plasma/Containment

#X-KDE-ParentApp=plasma-desktop
X-Plasma-API=declarativeappletscript
X-Plasma-MainScript=ui/main.qml
X-KDE-PluginInfo-Author=Homerun Developers
X-KDE-PluginInfo-Name=org.kde.homerun
X-KDE-PluginInfo-Version=@HOMERUN_VERSION@
X-KDE-PluginInfo-Website=http://userbase.kde.org/Homerun
X-KDE-PluginInfo-Category=Application Launchers
X-KDE-PluginInfo-Depends=
X-KDE-PluginInfo-License=GPL v2+
X-KDE-PluginInfo-EnabledByDefault=true
X-Plasma-DefaultSize=290,340
X-Plasma-ContainmentCategories=desktop
